@@ -2,13 +2,15 @@ from collections.abc import Iterable
 import csv
 import subprocess
 
-from .label import _tpl_label
-from .curve import _tpl_curve
-from .legend import _tpl_legend
+from .annotations.label import _tpl_label
+from .curve.curve import _tpl_curve
+from .annotations.legend import _tpl_legend
 from .strutils import _savetext, _compactify
 from .logmodes import _tpl_logmodes
-from .ticklabel import _tpl_ticklabel
+from .annotations.ticklabel import _tpl_ticklabel
 from .cycle_list import _tpl_cycle_list
+from .limits import _tpl_limits
+from .attribute import _tpl_attribute_variable
 
 
 class figure:
@@ -28,6 +30,8 @@ class figure:
     self.__logmodes: _tpl_logmodes = _tpl_logmodes()
     self.__additional_axis_cmds: list[str] = []
     self.__cycle_list: _tpl_cycle_list = _tpl_cycle_list("multi")
+    self.__limits: _tpl_limits = _tpl_limits()
+    self.__title: _tpl_attribute_variable = _tpl_attribute_variable(token="title")
 
   def plot(self, x: Iterable, y: Iterable, xerror: Iterable = None, yerror: Iterable = None,
            *args, **kwargs):
@@ -93,6 +97,10 @@ class figure:
   def set_ylabel(self, label: str):
     self.__ylabel.text.set_value(label)
 
+  def set_title(self, title: str):
+    fulltitle = '{' + title + '}' if title is not None else None
+    self.__title.set_value(fulltitle)
+
   def set_xprecision(self, precision: int):
     self.__xticklabel._set_precision(precision)
     self.set_fixed_x_ticks(True)
@@ -133,6 +141,12 @@ class figure:
   def set_y_tick_labels(self, labels: list[str] = None):
     self.__yticklabel._set_tick_labels(labels)
 
+  def set_xlim(self, left: float = None, right: float = None):
+    self.__limits.set_xlim(left, right)
+
+  def set_ylim(self, left: float = None, right: float = None):
+    self.__limits.set_ylim(left, right)
+
   def set_legend_position(self, pos: str):
     self.__legend._set_position(pos)
 
@@ -172,6 +186,7 @@ class figure:
   tick label style={{
     font=\\large
   }},
+  {self.__title}
   {self.__xticklabel}
   {self.__yticklabel}
   {self.__legend.pos}
@@ -181,6 +196,7 @@ class figure:
   scale only axis,
   {self.__logmodes.x}
   {self.__logmodes.y}
+  {self.__limits}
   {self.__cycle_list}"""
     body_cmd += ''.join(["\n  " + x + "," for x in self.__additional_axis_cmds])
     body_cmd += "\n]\n\n"
